@@ -6,7 +6,7 @@ use Cwd 'abs_path';
 use Exporter 'import';
 use Panda::Install::Payload;
 
-our $VERSION = '1.2.6';
+our $VERSION = '1.2.7';
 
 our @EXPORT_OK = qw/write_makefile makemaker_args/;
 our @EXPORT;
@@ -221,13 +221,23 @@ sub process_CLIB {
     return unless @$clib;
     
     foreach my $info (@$clib) {
-        my $make = '$(MAKE)';
-        $make = 'gmake' if $info->{GMAKE} and $^O eq 'freebsd';
+        my $build_cmd = $info->{BUILD_CMD};
+        my $clean_cmd = $info->{CLEAN_CMD};
+        
+        unless ($build_cmd) {
+            my $make = '$(MAKE)';
+            $make = 'gmake' if $info->{GMAKE} and $^O eq 'freebsd';
+            $info->{TARGET} ||= '';
+            $info->{FLAGS} ||= '';
+            $build_cmd = "$make $info->{FLAGS} $info->{TARGET}";
+            $clean_cmd = "$make clean";
+        }
+        
         my $path = $info->{DIR}.'/'.$info->{FILE};
         $clibs .= "$path ";
-        $info->{TARGET} ||= ''; $info->{FLAGS} ||= '';
-        $params->{postamble}{clib_build} .= "$path : ; cd $info->{DIR} && $make $info->{FLAGS} $info->{TARGET}\n";
-        $params->{postamble}{clib_clean} .= "clean :: ; cd $info->{DIR} && $make clean\n";
+        
+        $params->{postamble}{clib_build} .= "$path : ; cd $info->{DIR} && $build_cmd\n";
+        $params->{postamble}{clib_clean} .= "clean :: ; cd $info->{DIR} && $clean_cmd\n" if $clean_cmd;
         push @{$params->{OBJECT}}, $path;
     }
     $params->{postamble}{clib_ldep} = "linkext:: $clibs";
